==> inspec-ai-0.1.12.tar.gz: inspec-ai-0.1.12/README.md <==
# inspec-ai
[![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)
![CI](https://github.com/moovai/inspec/actions/workflows/ci.yml/badge.svg)


This library contains all the prototypes that were developped by the Moov AI product team.   

## Installation

To add inSpec to your project, you can run the following command:

```
pip install inspec-ai
```

NOTE: inspec-ai was developped using Python 3.9.

## Documentation

For more information on each specific function, please consult their specific documentation page in the `docs/` folder on the repository.
## License

Copyright (c) 2022 MoovAI Technologies Inc.

Permission is hereby granted, free of charge, to any person or organization
obtaining a copy of this software and associated documentation files
(the "Software"), to use, copy and distribute the Software within the
internal operations of aforementioned person or organization. It is
strictly forbidden to publish, externally distribute, sublicense, lease or
sell copies or use of the Software or any derived work, without explicit
authorization from MoovAI Technologies Inc.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.

==> inspec-ai-0.1.15.tar.gz: inspec-ai-0.1.15/README.md <==
# inspec-ai
[![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)
![CI](https://github.com/moovai/inspec/actions/workflows/ci.yml/badge.svg)


This library contains all the prototypes that were developped by the Moov AI product team.   

## Installation

To add inSpec to your project, you can run the following command:

```
pip install inspec-ai
```

NOTE: inspec-ai was developed using Python 3.9.

## Documentation

For more information on each specific function, please consult their specific documentation page in the `docs/` folder on the repository.
## License

Copyright (c) 2022 MoovAI Technologies Inc.

Permission is hereby granted, free of charge, to any person or organization
obtaining a copy of this software and associated documentation files
(the "Software"), to use, copy and distribute the Software within the
internal operations of aforementioned person or organization. It is
strictly forbidden to publish, externally distribute, sublicense, lease or
sell copies or use of the Software or any derived work, without explicit
authorization from MoovAI Technologies Inc.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.
